col_types: Get the types of the columns of a RelTableModel object

View source: R/RelTableModel.R

col_typesR Documentation

Get the types of the columns of a RelTableModel object

Description

Get the types of the columns of a RelTableModel object

Usage

col_types(x)

Arguments

x

a RelTableModel object

Value

A col_spec object with the type of each column


ReDaMoR documentation built on May 19, 2026, 9:08 a.m.