confront_table_data: Confront a RelTableModel to actual data

View source: R/RelTableModel.R

confront_table_dataR Documentation

Confront a RelTableModel to actual data

Description

Confront a RelTableModel to actual data

Usage

confront_table_data(x, d, checks = c("unique", "not nullable"))

Arguments

x

a RelTableModel

d

a data frame or a matrix for matrix model

checks

a character vector with the name of optional checks to be done (Default: all of them c("unique", "not nullable"))

Value

A report as a list


ReDaMoR documentation built on May 19, 2026, 9:08 a.m.