correct_constraints: Correct the constraints of a table to make them consistent

View source: R/RelTableModel.R

correct_constraintsR Documentation

Correct the constraints of a table to make them consistent

Description

Correct the constraints of a table to make them consistent

Usage

correct_constraints(x, createPKIndex = FALSE)

Arguments

x

a RelTableModel object

createPKIndex

should an index be create for the primary key (default: FALSE)


ReDaMoR documentation built on May 19, 2026, 9:08 a.m.