Learn R Programming

ReDaMoR (version 1.0.1)

col_types: Get the types of the columns of a RelTableModel object

Description

Get the types of the columns of a RelTableModel object

Usage

col_types(x)

Value

A col_spec object with the type of each column

Arguments

x

a RelTableModel object