Skip to contents

Correct the constraints of a table to make them consistent

Usage

correct_constraints(x, createPKIndex = FALSE)

Arguments

x

a RelTableModel object

createPKIndex

should an index be create for the primary key (default: FALSE)