Correct the constraints of a table to make them consistent
Source:R/RelTableModel.R
correct_constraints.RdCorrect the constraints of a table to make them consistent
Arguments
- x
a RelTableModel object
- createPKIndex
should an index be create for the primary key (default: FALSE)